sequencetools.map_sequence_elements_to_numbered_sublists
========================================================

.. autofunction:: abjad.tools.sequencetools.map_sequence_elements_to_numbered_sublists.map_sequence_elements_to_numbered_sublists
